# API Reference

::: any_agent.AnyAgent

::: any_agent.AgentFramework

::: any_agent.AgentConfig

::: any_agent.config.MCPStdioParams

::: any_agent.config.MCPSseParams

::: any_agent.config.TracingConfig

::: any_agent.tools

::: any_agent.tracing
